#!/usr/bin/perl -w

=head1 NAME

Debconf::Element::Gnome - gnome UI element

=cut

package Debconf::Element::Gnome;
use strict;
use utf8;
use Gtk2;
use Debconf::Gettext;
use Debconf::Encoding qw(to_Unicode);
use base qw(Debconf::Element);

=head1 DESCRIPTION

This is a type of Element used by the gnome FrontEnd. It contains a hbox,
into which the gnome UI element and any associated lables, help buttons,
etc, are packaged.

=head1 FIELDS

=over 4

=item hbox

This is the hbox that holds all the widgets for this element.

=back

=head1 METHODS

=over 4

=item init

Sets up the vbox.

=cut

sub init {
	my $this=shift;

	$this->vbox(Gtk2::VBox->new(0, 5));
	$this->vbox->show;

	# default is not to be expanded or to filled
	$this->fill(0);
	$this->expand(0);
	$this->multiline(0);
}

=item addwidget

Packs the passed widget into the hbox.

=cut

sub addwidget {
	my $this=shift;
	my $widget=shift;

	$this->vbox->pack_start($widget, 1, 1, 0);
}

=item adddescription

Packs a label containing the short description into the hbox.

=cut

sub adddescription {
	my $this=shift;
	my $description=to_Unicode($this->question->description);
	
	my $label=Gtk2::Label->new($description);
    $label->set_alignment(0, 0.5);
	$label->set_line_wrap(1);
	$label->show;
	$this->vbox->pack_start($label, 0, 0, 0);
}

=item addhelp

Packs a help button into the hbox. The button is omitted if there is no
extended description to display as help.

=cut

sub addhelp {
	my $this=shift;
	
	my $help=$this->question->extended_description;
	return unless length $help;
	my $label = Gtk2::Label->new();
	$label->set_markup("<small>" . to_Unicode($help) . "</small>");
	$label->set_line_wrap(1);
	$label->show;
	$this->vbox->pack_end($label, 0, 0, 0);
}

=item value

Return the value the user entered.

Defaults to returning nothing.

=cut

sub value {
	my $this=shift;

	return '';
}

=back

=head1 AUTHOR

Eric Gillespie <epg@debian.org>
Gustavo Noronha Silva <kov@debian.org>
Evan Dandrea <ev@ubuntu.com>

=cut

1
